==> haskell-hls-cabal-plugin-0.1.0.0-216-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-cabal-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-cabal-plugin
version:              0.1.0.0
visibility:           public
id:                   hls-cabal-plugin-0.1.0.0-ClMQ0sqf9OTIbJch7CJ7m2
key:                  hls-cabal-plugin-0.1.0.0-ClMQ0sqf9OTIbJch7CJ7m2
license:              MIT
maintainer:           fendor@posteo.de
author:               Fendor
synopsis:             Cabal integration plugin with Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  2a18cf1da410a41d1ecdd6df09c62814
exposed:              True
exposed-modules:
    Ide.Plugin.Cabal Ide.Plugin.Cabal.Diagnostics
    Ide.Plugin.Cabal.LicenseSuggest Ide.Plugin.Cabal.Parse

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hls-cabal-plugin-0.1.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hls-cabal-plugin-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-cabal-plugin
hs-libraries:         HShls-cabal-plugin-0.1.0.0-ClMQ0sqf9OTIbJch7CJ7m2
depends:
    Cabal-3.6.3.0 base-4.16.4.0 bytestring-0.11.4.0 deepseq-1.4.6.1
    directory-1.3.6.2 extra-1.7.16-KR1Y4egVNjKBcN1wDcWpKS
    ghcide-1.10.0.0-ANlEi69wfG3LLHXTGtAddY
    hashable-1.4.4.0-BrYG523VafVKM4yDK0K7G3
    hls-graph-1.9.0.0-JdUlZol8TlX5JgxZobn6H
    hls-plugin-api-1.6.0.0-1E7kwkfpka34t1TV7dkYk6
    lsp-1.6.0.0-Fm3bPcTc1xJ3BY9cZfhboY
    lsp-types-1.6.0.0-HhZ6mX8WaNU74nva3O4wpr
    regex-tdfa-1.3.2.2-9zKmqEaVx0vIf4YwE2VWyu stm-2.5.0.2 text-1.2.5.0
    unordered-containers-0.2.20-HYi8F0R2X5DJGcgMLraHLn

haddock-interfaces:
    /usr/share/doc/haskell-hls-cabal-plugin/html/hls-cabal-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-cabal-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-cabal-plugin-0.1.0.0-217-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-cabal-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-cabal-plugin
version:              0.1.0.0
visibility:           public
id:                   hls-cabal-plugin-0.1.0.0-4VsoVekyxca3NCuUTNy8cp
key:                  hls-cabal-plugin-0.1.0.0-4VsoVekyxca3NCuUTNy8cp
license:              MIT
maintainer:           fendor@posteo.de
author:               Fendor
synopsis:             Cabal integration plugin with Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  8275623d77a4496be6cbcdb119b1d9f6
exposed:              True
exposed-modules:
    Ide.Plugin.Cabal Ide.Plugin.Cabal.Diagnostics
    Ide.Plugin.Cabal.LicenseSuggest Ide.Plugin.Cabal.Parse

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hls-cabal-plugin-0.1.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hls-cabal-plugin-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-cabal-plugin
hs-libraries:         HShls-cabal-plugin-0.1.0.0-4VsoVekyxca3NCuUTNy8cp
depends:
    Cabal-3.6.3.0 base-4.16.4.0 bytestring-0.11.4.0 deepseq-1.4.6.1
    directory-1.3.6.2 extra-1.7.16-KR1Y4egVNjKBcN1wDcWpKS
    ghcide-1.10.0.0-7c9krgBmaEqEyGtNTEt4bF
    hashable-1.4.4.0-BrYG523VafVKM4yDK0K7G3
    hls-graph-1.9.0.0-JdUlZol8TlX5JgxZobn6H
    hls-plugin-api-1.6.0.0-5o61tOk1rYK4T6l0JlvRvS
    lsp-1.6.0.0-J94lOF1VLJ85AbgOSZqiHi
    lsp-types-1.6.0.0-HhZ6mX8WaNU74nva3O4wpr
    regex-tdfa-1.3.2.2-9zKmqEaVx0vIf4YwE2VWyu stm-2.5.0.2 text-1.2.5.0
    unordered-containers-0.2.20-HYi8F0R2X5DJGcgMLraHLn

haddock-interfaces:
    /usr/share/doc/haskell-hls-cabal-plugin/html/hls-cabal-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-cabal-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
